==> twify-0.1.1.tgz: package/README.md <==
# :unicorn: Twify

![Build](https://img.shields.io/github/workflow/status/tzsk/twify/CI/main?logo=github&style=for-the-badge)
[![npm](https://img.shields.io/npm/v/twify?logo=npm&style=for-the-badge)](https://www.npmjs.com/package/twify)
[![npm](https://img.shields.io/npm/dt/twify?logo=npm&style=for-the-badge)](https://www.npmjs.com/package/twify)

A simple tool to setup [Tailwind CSS](https://tailwindcss.com/) in your fresh project with a Single Command.

## :fire: How It Works

Here is a screen grab of how it looks.

![Twify](./assets/twify.png)

## :gift: Installation

Scaffold a new project of your choice then simply run,

```sh
npx twify init
```

## :star: Supported Projects

Below are the list of Supported Projects,

| **Framework**    | **Javascript**     | **Typescript**     |
|------------------|--------------------|--------------------|
| Next JS          | :white_check_mark: | :white_check_mark: |
| Remix            | :white_check_mark: | :white_check_mark: |
| Nuxt 2           | :white_check_mark: | :white_check_mark: |
| Nuxt 3           | :white_check_mark: | :white_check_mark: |
| Svelte Kit       | :white_check_mark: | :white_check_mark: |
| Laravel Mix      | :o: WIP            | :o: WIP            |
| Laravel Vite     | :o: WIP            | :o: WIP            |
| Gatsby           | :o: WIP            | :o: WIP            |
| Vite             | :o: WIP            | :o: WIP            |
| Angular          | :o: WIP            | :o: WIP            |
| Create React App | :o: WIP            | :o: WIP            |


## :microscope: Testing

After Cloning the repository, install all npm dependencies by running: `npm install`.

Then Run Tests:

```bash
$ npm run test
$ npm run coverage
```

## :date: Change log

Please see [release history][link-releases] for more information on what has changed recently.

## :heart: Contributing

Please feel free to contribute ideas and PRs are most welcome.

## :crown: Credits

- [Kazi Mainuddin Ahmed][link-author]
- [All Contributors][link-contributors]

## :policeman: License

The MIT License (MIT). Please see [License File](LICENSE.md) for more information.

[link-author]: https://github.com/tzsk
[link-contributors]: ../../contributors
[link-releases]: ../../releases

==> twify-0.2.0.tgz: package/README.md <==
# :unicorn: Twify

![Build](https://img.shields.io/github/workflow/status/tzsk/twify/CI/main?logo=github&style=for-the-badge)
[![npm](https://img.shields.io/npm/v/twify?logo=npm&style=for-the-badge)](https://www.npmjs.com/package/twify)
[![npm](https://img.shields.io/npm/dt/twify?logo=npm&style=for-the-badge)](https://www.npmjs.com/package/twify)
![GitHub top language](https://img.shields.io/github/languages/top/tzsk/twify?logo=typescript&style=for-the-badge)

A simple tool to setup [Tailwind CSS](https://tailwindcss.com/) in your fresh project with a Single Command.

## :fire: How It Works

Here is a screen grab of how it looks.

![Twify](./assets/twify.png)

## :gift: Installation

Scaffold a new project of your choice then simply run,

```sh
npx twify init
```

## :star: Supported Projects

Below are the list of Supported Projects,

| **Framework**    | **Javascript**     | **Typescript**     |
|------------------|--------------------|--------------------|
| Next JS          | :white_check_mark: | :white_check_mark: |
| Remix            | :white_check_mark: | :white_check_mark: |
| Nuxt 2           | :white_check_mark: | :white_check_mark: |
| Nuxt 3           | :white_check_mark: | :white_check_mark: |
| Svelte Kit       | :white_check_mark: | :white_check_mark: |
| Laravel Mix      | :o: WIP            | :o: WIP            |
| Laravel Vite     | :o: WIP            | :o: WIP            |
| Gatsby           | :o: WIP            | :o: WIP            |
| Vite             | :white_check_mark: | :white_check_mark: |
| Angular          | :white_check_mark: | :white_check_mark: |
| Create React App | :white_check_mark: | :white_check_mark: |


## :microscope: Testing

After Cloning the repository, install all npm dependencies by running: `npm install`.

Then Run Tests:

```bash
$ npm run test
$ npm run coverage
```

## :date: Change log

Please see [release history][link-releases] for more information on what has changed recently.

## :heart: Contributing

Please feel free to contribute ideas and PRs are most welcome.

## :crown: Credits

- [Kazi Mainuddin Ahmed][link-author]
- [All Contributors][link-contributors]

## :policeman: License

The MIT License (MIT). Please see [License File](LICENSE.md) for more information.

[link-author]: https://github.com/tzsk
[link-contributors]: ../../contributors
[link-releases]: ../../releases
